import sys
import math
import time
import random
import configparser
from functools import wraps


# ANSI escape codes for colors
ANSI_COLORS = {
    "black": "\033[30m",
    "red": "\033[31m",
    "green": "\033[32m",
    "yellow": "\033[33m",
    "blue": "\033[34m",
    "magenta": "\033[35m",
    "cyan": "\033[36m",
    "white": "\033[37m",
    "bright_black": "\033[90m",
    "bright_red": "\033[91m",
    "bright_green": "\033[92m",
    "bright_yellow": "\033[93m",
    "bright_blue": "\033[94m",
    "bright_magenta": "\033[95m",
    "bright_cyan": "\033[96m",
    "bright_white": "\033[97m",
    "reset": "\033[0m",  # Reset to default color
}


def remove_prefix_suffix(model):
    count = str(model).count("-")
    return "-".join(model.split("-")[1:-1]) if count >= 3 else model


def load_config(config_path):
    """Helper function to load the configuration file."""
    config_parser = configparser.ConfigParser()
    config_parser.read(config_path)
    print("Configuration File Content:")
    for section in config_parser.sections():
        print(f"[{section}]")
        for key, value in config_parser.items(section):
            print(f"{key} = {value}")
    return config_parser


def get_number_of_pages(total_count, page_size=100):
    number_pages = abs((total_count - 1) / page_size)
    return math.floor(number_pages) + 1


def renew_jwt(method):
    @wraps(method)
    def _impl(self, *args, **kwargs):
        valid_jwt = (time.time() - getattr(self, "last_refresh_time")) / 60 < 14
        if not valid_jwt and self.refresh:
            self.refresh_jwt_token()
        method_output = method(self, *args, **kwargs)
        return method_output

    return _impl


def get_random_color():
    """Return a random ANSI color code."""
    color_name = random.choice(list(ANSI_COLORS.keys())[:-1])  # Exclude 'reset' color
    return ANSI_COLORS[color_name]


def print_color(content, color=None):
    try:
        color = (
            ANSI_COLORS.get(color.lower(), ANSI_COLORS["black"])
            if color
            else get_random_color()
        )

        if sys.stdout.isatty():
            # Use ANSI codes for color if supported by the terminal
            print(f"{color}{content}{ANSI_COLORS['reset']}")
        else:
            # Fallback to default text if terminal doesn't support colors
            print(f"{content}")

    except Exception as e:
        print(f"Error printing section: {e}")


def print_section(title, color=None):
    return print_color(f" {title} ".center(130, "="), color)
